==> qtjambi-qt3drender-jre8-6.2.2-sources.jar: io/qt/qt3d/render/QtJambi_LibraryUtilities.java <==
package io.qt.qt3d.render;

final class QtJambi_LibraryUtilities {
    static{
        try {
            io.qt.QtUtilities.initializePackage("io.qt.internal");
            io.qt.QtUtilities.loadQtLibrary("Concurrent");
            io.qt.QtUtilities.loadQtLibrary("Gui");
            io.qt.QtUtilities.loadQtLibrary("Network");
            io.qt.QtUtilities.loadQtLibrary("3DCore");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("libGLESv2"))
                io.qt.QtUtilities.loadUtilityLibrary("libGLESv2");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("libEGL"))
                io.qt.QtUtilities.loadUtilityLibrary("libEGL");
            if(io.qt.QtUtilities.isAvailableQtLibrary("ANGLE"))
                io.qt.QtUtilities.loadQtLibrary("ANGLE");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("opengl32sw"))
                io.qt.QtUtilities.loadUtilityLibrary("opengl32sw");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("d3dcompiler_47"))
                io.qt.QtUtilities.loadUtilityLibrary("d3dcompiler_47");
            io.qt.QtUtilities.loadQtLibrary("OpenGL");
            io.qt.QtUtilities.loadQtLibrary("3DRender");
            io.qt.QtUtilities.loadQtJambiLibrary("3DRender");
        } catch(RuntimeException | Error t) {
            throw t;
        } catch(Throwable t) {
            throw new RuntimeException(t);
        }
    }

    static final io.qt.InternalAccess internal = internalAccess();

    private static native io.qt.InternalAccess internalAccess();

    static void initialize() { };

    private QtJambi_LibraryUtilities() throws java.lang.InstantiationError { throw new java.lang.InstantiationError("Cannot instantiate QtJambi_LibraryUtilities."); }
}

==> qtjambi-qt3drender-jre8-6.2.3-sources.jar: io/qt/qt3d/render/QtJambi_LibraryUtilities.java <==
package io.qt.qt3d.render;

final class QtJambi_LibraryUtilities {
    static{
        try {
            io.qt.QtUtilities.initializePackage("io.qt.internal");
            io.qt.QtUtilities.loadQtLibrary("Concurrent");
            io.qt.QtUtilities.loadQtLibrary("Gui");
            io.qt.QtUtilities.loadQtLibrary("Network");
            io.qt.QtUtilities.loadQtLibrary("3DCore");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("libGLESv2"))
                io.qt.QtUtilities.loadUtilityLibrary("libGLESv2");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("libEGL"))
                io.qt.QtUtilities.loadUtilityLibrary("libEGL");
            if(io.qt.QtUtilities.isAvailableQtLibrary("ANGLE"))
                io.qt.QtUtilities.loadQtLibrary("ANGLE");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("opengl32sw"))
                io.qt.QtUtilities.loadUtilityLibrary("opengl32sw");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("d3dcompiler_47"))
                io.qt.QtUtilities.loadUtilityLibrary("d3dcompiler_47");
            io.qt.QtUtilities.loadQtLibrary("OpenGL");
            io.qt.QtUtilities.loadQtLibrary("3DRender");
            io.qt.QtUtilities.loadQtJambiLibrary("3DRender");
        } catch(Error t) {
            throw t;
        } catch(Throwable t) {
            throw new ExceptionInInitializerError(t);
        }
    }

    static final io.qt.InternalAccess internal = internalAccess();

    private static native io.qt.InternalAccess internalAccess();

    static void initialize() { };

    private QtJambi_LibraryUtilities() throws java.lang.InstantiationError { throw new java.lang.InstantiationError("Cannot instantiate QtJambi_LibraryUtilities."); }
}
